@@ -89,6 +89,7 @@ demo_getc_blocking(struct notcurses* nc, ncinput* ni){
 
 /*-------------------------------time helpers----------------------------*/
 #define GIG 1000000000ul
+#define MAXSLEEP (GIG / 80) // nanoseconds
 
 static inline uint64_t
 timespec_to_ns(const struct timespec* ts){
@@ -145,7 +146,7 @@ timespec_mul(const struct timespec* ts, unsigned multiplier, struct timespec* pr
 
 /*---------------------------------FPS plot-------------------------------*/
 int fpsgraph_init(struct notcurses* nc);
-int fpsgraph_stop(struct notcurses* nc);
+int fpsgraph_stop(void);
 int fpsplot_grab(int y);
 int fpsplot_release(void);
 /*----------------------------------HUD----------------------------------*/
