@@ -256,7 +256,7 @@ cell_egc_idx(const cell* c){
 // Is the cell simple (a UTF8-encoded EGC of four bytes or fewer)?
 static inline bool
 cell_simple_p(const cell* c){
-  return (htole(c->gcluster) & 0xff000000ul) != 0x01000000ul;
+  return (htole(c->gcluster) & htole(0xff000000ul)) != htole(0x01000000ul);
 }
 
 // only applies to complex cells, do not use on simple cells
