@@ -954,6 +954,7 @@ egc_rtl(const char* egc, int* bytes){
   char* s = (char*)malloc(*bytes + sizeof(LTRMARK)); // cast for C++ callers
   memcpy(s, egc, *bytes);
   memcpy(s + *bytes, LTRMARK, sizeof(LTRMARK));
+  *bytes += strlen(LTRMARK);
   return s;
 }
 
@@ -970,7 +971,6 @@ pool_blit_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int co
   if(bytes <= 4){
     c->gcluster = 0;
     memcpy(&c->gcluster, gcluster, bytes);
-    c->gcluster = htole(c->gcluster);
     return bytes;
   }
   int eoffset = egcpool_stash(pool, gcluster, bytes);
