@@ -766,6 +766,7 @@ stash_stats(notcurses* nc){
   nc->stashstats.bgemissions += nc->stats.bgemissions;
   nc->stashstats.defaultelisions += nc->stats.defaultelisions;
   nc->stashstats.defaultemissions += nc->stats.defaultemissions;
+  nc->stashstats.refreshes += nc->stats.refreshes;
   // fbbytes aren't stashed
   reset_stats(&nc->stats);
 }
@@ -1227,11 +1228,13 @@ int notcurses_stop(notcurses* nc){
                 nc->stashstats.render_bytes / (double)nc->stashstats.renders / 1024);
       }
       if(nc->stashstats.renders || nc->stashstats.failed_renders){
-        fprintf(stderr, "%.1f theoretical FPS, %ju failed render%s\n",
+        fprintf(stderr, "%.1f theoretical FPS, %ju failed render%s, %ju refresh%s\n",
                 nc->stashstats.renders ?
                   NANOSECS_IN_SEC * (double)nc->stashstats.renders / nc->stashstats.render_ns : 0.0,
                 nc->stashstats.failed_renders,
-                nc->stashstats.failed_renders == 1 ? "" : "s");
+                nc->stashstats.failed_renders == 1 ? "" : "s",
+                nc->stashstats.refreshes,
+                nc->stashstats.refreshes == 1 ? "" : "es");
         fprintf(stderr, "RGB emits:elides: def %ju:%ju fg %ju:%ju bg %ju:%ju\n",
                 nc->stashstats.defaultemissions,
                 nc->stashstats.defaultelisions,
@@ -2213,20 +2216,28 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
   if(n->boundto == newparent){
     return n;
   }
-  if(n->boundto == n){ // children become new root planes
-    for(ncplane* child = n->blist ; child ; child = child->bnext){
-      child->boundto = child;
-    }
-  }else{ // children are rebound to current parent
-    if(n->blist){
+  if(n->blist){
+    // FIXME these both look to throw away siblings following n->blist :/
+    if(n->boundto == n){ // children become new root planes
+      for(ncplane* child = n->blist ; child ; child = child->bnext){
+        child->boundto = child;
+      }
+      /* FIXME FIXME FIXME
+      n->blist->bnext = ncplane_pile(n)->root;
+      n->blist->bnext->bprev = &n->blist->bnext;
+      n->blist->bprev = &ncplane_pile(n)->root;
+      ncplane_pile(n)->root = n->blist;
+      */
+    }else{ // children are rebound to current parent
       if( (n->blist->bnext = n->boundto->blist) ){
         n->boundto->blist->bprev = &n->blist->bnext;
       }
       n->blist->bprev = &n->boundto->blist;
       n->boundto->blist = n->blist;
-      n->blist = NULL;
     }
+    n->blist = NULL;
   }
+//notcurses_debug(ncplane_notcurses(n), stderr);
   return ncplane_reparent_family(n, newparent);
 }
 
@@ -2271,6 +2282,9 @@ ncplane* ncplane_reparent_family(ncplane* n, ncplane* newparent){
   if(n == ncplane_notcurses(n)->stdplane){
     return NULL; // can't reparent standard plane
   }
+  if(ncplane_descendant_p(newparent, n)){
+    return NULL;
+  }
   if(n->boundto == newparent){ // no-op
     return n;
   }
