@@ -104,8 +104,8 @@ TEST_CASE("Wide") {
     }
   }
 
-  // Placing a wide char to the immediate left of any other char ought obliterate
-  // that cell.
+  // Placing a wide char to the immediate left of any other char ought
+  // obliterate that cell.
   SUBCASE("WideCharAnnihilatesRight") {
     const char* w = FROG;
     const char* wbashed = SCORPION;
@@ -132,8 +132,6 @@ TEST_CASE("Wide") {
     CHECK(0 == strcmp(cell_extended_gcluster(n_, &c), FROG));
     ncplane_at_yx_cell(n_, 1, 1, &c);
     CHECK(ncstrwidth(FROG) == 1 + cell_double_wide_p(&c)); //should be wide
-    ncplane_at_yx_cell(n_, 0, 2, &c);
-    CHECK(0 == strlen(cell_extended_gcluster(n_, &c)));
     CHECK(0 == notcurses_render(nc_)); // should be nothing
   }
 
@@ -935,14 +933,14 @@ TEST_CASE("Wide") {
   // Verify that we can use long (4-byte) UTF-encoded characters together with
   // styles without a problem (since the stylemask holds both styling bits and
   // the NUL backstop for long inlined UTF8).
-  // U+1F90C PINCHED FINGERS → UTF8(f0 9f a4 8c)
+  // U+1F427 PINCHED FINGERS → UTF8(f0 9f a4 8c)
   SUBCASE("ItalicEmoji") {
     cell c = CELL_TRIVIAL_INITIALIZER;
-    cell_load(n_, &c, "\U0001F90C");
-    CHECK(0x8ca49ff0lu == c.gcluster);
+    cell_load(n_, &c, "\U0001F427");
+    CHECK(0xa7909ff0 == htole(c.gcluster));
     cell_on_styles(&c, NCSTYLE_ITALIC);
     CHECK(4 == strlen(cell_extended_gcluster(n_, &c)));
-    CHECK(0 == strcmp("\U0001F90C", cell_extended_gcluster(n_, &c)));
+    CHECK(0 == strcmp("\U0001F427", cell_extended_gcluster(n_, &c)));
     CHECK(0 < ncplane_putc_yx(n_, 0, 0, &c));
     CHECK(0 == notcurses_render(nc_));
     uint16_t stylemask;
@@ -950,18 +948,18 @@ TEST_CASE("Wide") {
     auto egc = notcurses_at_yx(nc_, 0, 0, &stylemask, &channels);
     REQUIRE(nullptr != egc);
     CHECK(4 == strlen(egc));
-    CHECK(0 == strcmp("\U0001F90C", egc));
+    CHECK(0 == strcmp("\U0001F427", egc));
     free(egc);
     CHECK(NCSTYLE_ITALIC == stylemask);
   }
 
   SUBCASE("StyleMaxEmoji") {
     cell c = CELL_TRIVIAL_INITIALIZER;
-    cell_load(n_, &c, "\U0001F90C");
-    CHECK(0x8ca49ff0lu == c.gcluster);
+    cell_load(n_, &c, "\U0001F427");
+    CHECK(0xa7909ff0 == htole(c.gcluster));
     cell_on_styles(&c, NCSTYLE_MASK);
     CHECK(4 == strlen(cell_extended_gcluster(n_, &c)));
-    CHECK(0 == strcmp("\U0001F90C", cell_extended_gcluster(n_, &c)));
+    CHECK(0 == strcmp("\U0001F427", cell_extended_gcluster(n_, &c)));
     CHECK(0 < ncplane_putc_yx(n_, 0, 0, &c));
     CHECK(0 == notcurses_render(nc_));
     uint16_t stylemask;
@@ -969,7 +967,7 @@ TEST_CASE("Wide") {
     auto egc = notcurses_at_yx(nc_, 0, 0, &stylemask, &channels);
     REQUIRE(nullptr != egc);
     CHECK(4 == strlen(egc));
-    CHECK(0 == strcmp("\U0001F90C", egc));
+    CHECK(0 == strcmp("\U0001F427", egc));
     free(egc);
     CHECK(NCSTYLE_MASK == stylemask);
   }
